@@ -4,6 +4,7 @@ mod key; pub(crate) use key::*;
 mod location; pub(crate) use location::*;
 mod map; pub(crate) use map::*;
 mod num; pub(crate) use num::*;
+mod r#enum; pub(crate) use r#enum::*;
 mod seq; pub(crate) use seq::*;
 
 pub struct Deserializer<R: buffered_reader::BufferedReader<()>> {
@@ -21,7 +22,7 @@ impl<R: buffered_reader::BufferedReader<()>> Deserializer<R> {
 		}
 	}
 
-	fn parse_inline_string(&mut self) -> Result<Option<(std::borrow::Cow<str>, crate::Location)>, DeserializeError> {
+	fn parse_inline_string(&mut self) -> Result<(std::borrow::Cow<str>, crate::Location), DeserializeError> {
 		let len = self.input.read_to(b'\n')?.len();
 		let mut b = &self.input.consume(len)[..len];
 
@@ -43,11 +44,7 @@ impl<R: buffered_reader::BufferedReader<()>> Deserializer<R> {
 				.at(location))
 		}
 
-		if !content.is_empty() {
-			Ok(Some((std::borrow::Cow::from(content), location)))
-		} else {
-			Ok(None)
-		}
+		Ok((std::borrow::Cow::from(content), location))
 	}
 
 	fn parse_indented_string(&mut self) -> Result<(std::borrow::Cow<str>, Location), DeserializeError> {
@@ -121,7 +118,8 @@ impl<R: buffered_reader::BufferedReader<()>> Deserializer<R> {
 	}
 
 	fn parse_string(&mut self) -> Result<(std::borrow::Cow<str>, crate::Location), DeserializeError> {
-		if let Some((s, location)) = self.parse_inline_string()? {
+		let (s, location) = self.parse_inline_string()?;
+		if !s.is_empty() {
 			// IDK why rust forces us to copy this.
 			Ok((std::borrow::Cow::from(s.into_owned()), location))
 		} else {
@@ -138,7 +136,7 @@ impl<R: buffered_reader::BufferedReader<()>> Deserializer<R> {
 		}
 
 		let s = crate::from_utf8(b, self.location)?;
-		let mut content = s.trim();
+		let content = s.trim();
 
 		if !content.is_empty() {
 			let content_ptr = content.as_ptr();
@@ -311,7 +309,7 @@ impl<'d, R: buffered_reader::BufferedReader<()>> serde::de::Deserializer<'d> for
 		match self.peek_line()? {
 			"none" => {
 				// TODO: Fix peek_line to avoid this possibility.
-				let (mut s, location) = dbg!(self.parse_string())?;
+				let (s, location) = self.parse_string()?;
 				let s = if let Some(comment_start) = s.bytes().position(|c| c == b'#') {
 					&s[..comment_start]
 				} else {
@@ -390,12 +388,38 @@ impl<'d, R: buffered_reader::BufferedReader<()>> serde::de::Deserializer<'d> for
 	}
 
 	fn deserialize_enum<V: serde::de::Visitor<'d>>(
-		self,
-		_name: &'static str,
-		_variants: &'static [&'static str],
-		_visitor: V,
+		mut self,
+		name: &'static str,
+		variants: &'static [&'static str],
+		visitor: V,
 	) -> Result<V::Value, DeserializeError> {
-		Err(crate::DeserializeErrorKind::Unimplemented("deserialize_enum").at(self.location))
+		let (inline, location) = self.parse_inline_string()?;
+		if !inline.is_empty() {
+			return serde::de::IntoDeserializer::into_deserializer(inline)
+				.deserialize_enum(name, variants, visitor)
+				.map_err(|e: crate::DeserializeError| e.with_location(location))
+		}
+
+		let s = self.peek_line()?;
+		if s.contains(':') {
+			let indent_len = self.indent.as_ref().map(|s| s.len()).unwrap_or(0);
+			let r = visitor.visit_enum(EnumDeserializer {
+				root: &mut self,
+			});
+			self.indent.as_mut().unwrap().truncate(indent_len);
+			return r
+		}
+
+		let (s, location) = self.parse_indented_string()?;
+		let mut s = s.as_ref();
+		if let Some(comment_start) = s.find('#') {
+			if !s.contains('\n') {
+				s = &s[..comment_start].trim();
+			}
+		}
+		serde::de::IntoDeserializer::into_deserializer(s)
+			.deserialize_enum(name, variants, visitor)
+			.map_err(|e: crate::DeserializeError| e.with_location(location))
 	}
 
 	fn deserialize_identifier<V: serde::de::Visitor<'d>>(self, visitor: V) -> Result<V::Value, DeserializeError> {
