@@ -6,10 +6,7 @@ fn test_strings() {
 		bar: String,
 	}
 
-	let s = b"a: foobar\nbar: bazbaz\n";
-
-	let mut d = crate::Deserializer::from(buffered_reader::Memory::new(s));
-	let t = <Test as serde::de::Deserialize>::deserialize(&mut d).unwrap();
+	let t: Test = crate::from_bytes("a: foobar\nbar: bazbaz\n").unwrap();
 	assert_eq!(t, Test{a: "foobar".into(), bar: "bazbaz".into()})
 }
 
@@ -21,7 +18,7 @@ fn test_multiline_strings() {
 		spaces: String,
 	}
 
-	let s = b"
+	let t: Test = crate::from_bytes("
 		tabs:
 			this is so
 			# No comments
@@ -29,9 +26,6 @@ fn test_multiline_strings() {
 		spaces: # Comment
 		    this is so
 		    cool
-		";
-
-	let mut d = crate::Deserializer::from(buffered_reader::Memory::new(s));
-	let t = <Test as serde::de::Deserialize>::deserialize(&mut d).unwrap();
+	").unwrap();
 	assert_eq!(t, Test{tabs: "this is so\n# No comments\ncool".into(), spaces: "this is so\ncool".into()})
 }
